#!/bin/bash

# Permanent Envirionment Global Context
# This file should be "sourced"

# Gray Girling, 2011


find_domainname()
{   local dom=
    if ! dom=`domainname 2>/dev/null` || [ -z "$dom" ]; then
        if ! dom=`hostname -d 2>/dev/null`; then
            dom=localdomain
        fi
    fi
    echo $dom
}

context_domain()
{   find_domainname | tr '()' '_'
}

context_arch()
{   if [ -z "$OSARCH" ]; then
        OSARCH=`uname -o`
        case "$OSARCH" in
            *Linux) OSARCH="linux";;
            *) ;;
        esac
    fi
    echo $OSARCH | tr [:upper:] [:lower:]
}

context_host()
{   # echo "# get host on '$OSARCH'"
    OSARCH=`context_arch`
    case "$OSARCH" in
        cygwin | cygwin64 | solaris | pcsolaris | opensolaris)
            echo "`hostname`.`find_domainname`";;
        *)
            if ! hostname -f 2>/dev/null; then
                if [ -x /sbin/ifconfig ]; then
                    if ! iface=`/sbin/route -n 2>/dev/null | awk '/UG/ { print $8 }'`; then
                        iface=eth0
                    fi
                    if ! ip=`/sbin/ifconfig $iface 2>/dev/null | awk '/inet addr:/ { gsub("inet addr:", ""); print $1; }'`; then
                        ip=127.0.0.1
                    fi
                else
                        ip=127.0.0.1
                fi
                echo $ip
            fi;;
    esac
}

context_session()
{   local tty
    if tty=`tty`; then
        echo `echo $tty | tr '/ ' '_'`_`context_host | tr '/ .' '_'`
        return 0
    else
        # no tty input
        # echo "context: can't find session - no tty input">&2
        echo "background_`context_host | tr '/ .' '_'`"
        return 0
    fi
}

if [ -z "$OBJROOT" ]; then
    if [ -z "$DIR_PENV" ]; then
        DIR_PENV=$HOME/.objroot
        export DIR_PENV
    fi
    OBJROOT=$DIR_PENV/session/`context_session`.env
    export OBJROOT
fi
